



*Felix Bittmann, 2021
cap log close
log using "Output/logfile.txt", text replace

quiet do "Dos/Opera.do
keep if inlist(wave, 1, 2, 3, 4, 5)		//Wellen 1-5 behalten
drop if missing(gym)					//falsche Schulformen raus
drop if wave == 1 & tx80220 > 1			//Nichtteilnehmer raus
count if wave == 1

*Nur Leute, die in Welle 1 ueber der Medianleistung liegen*
sum leistung if wave == 1, det
gen temp1 = 1 if wave == 1 & leistung >= `r(p50)' & !missing(leistung)
replace temp1 = 0 if missing(temp1)
bysort ID_t: egen temp2 = max(temp1)
keep if temp2 == 1
drop temp1 temp2
count if wave == 1


*Nur Leute, die in Welle 1 hohe Aspirationen haben*
gen temp1 = aspi_ideal if wave == 1
bysort ID_t: egen temp2 = max(temp1)
keep if temp2 == 1
drop temp1 temp2
count if wave == 1


keep if alleteilnahmen == 1				//Teilnehmer in W1, W2 und W5
count if wave == 1
keep if sameschool == 1					//Immer gleicher Schultyp W1, W2 und W5
count if wave == 1
drop if missing(gym)					//Schulform immer bekannt
count if wave == 1


*Listwise deletion*
egen temp = rowmiss(gym female pareduc alter2011 leistung osten zusammenleben ///
	migration aspi_ideal mean_* math read score5 speed5) if wave == 1
fre temp
bysort ID_t: egen nmiss = max(temp)
drop temp
keep if nmiss == 0
count if wave == 1

bysort ID_t (wave): gen temp = 1 if wave == 1 & !missing(aspi_ideal) & ///
	!missing(aspi_ideal[_n+1]) & !missing(aspi_ideal[_n+4])
bysort ID_t: egen complete = max(temp)
drop temp
keep if complete == 1
count if wave == 1
bysort ID_t: egen ID_i2 = mode(ID_i), minmode		//Add missing school IDs
********************************************************************************	



*** Deskriptionstabellen ***
preserve
tab pareduc, gen(educ_)
tab migration, gen(mig_)
label var educ_1 "Less than upper secondary education"
label var educ_2 "Upper secondary education"
label var educ_3 "Higher education"
label var mig_1 "Both parents born in Germany"
label var mig_2 "One parent born abroad"
label var mig_3 "Both parents born abroad"

eststo D0: estpost summarize aspi_ideal educ_? gym female alter2011 ///
	math read score5 speed5 osten zusammenleben mig_? ///
	mean_highedu mean_aspi mean_leistung if wave == 1, det
esttab D0 using "Output/description.rtf", ///
	cells("count(fmt(0)) min(fmt(1)) max(fmt(1)) mean(fmt(2)) sd(fmt(2)) p50(fmt(1))") rtf replace ///
	label noobs
	
eststo D1: estpost summarize aspi_ideal educ_? gym female alter2011 ///
	math read score5 speed5 osten zusammenleben mig_? ///
	mean_highedu mean_aspi mean_leistung if wave == 1 & gym == 0, det
eststo D2: estpost summarize aspi_ideal educ_? gym female alter2011 ///
	math read score5 speed5 osten zusammenleben mig_? ///
	mean_highedu mean_aspi mean_leistung if wave == 1 & gym == 1, det
esttab D1 D2 using "Output/description_bytrack.rtf", ///
	cells("mean(fmt(2))") rtf replace ///
	label noobs
	
restore


*** Mediatoren nach Schulform ***
eststo D1: estpost summarize mean_* if gym == 0 & wave == 1, det
eststo D2: estpost summarize mean_* if gym == 1 & wave == 1, det
esttab D1 D2 using "Output/mediators.rtf", ///
	label cells("count(fmt(0)) mean(fmt(2)) sd(fmt(2))") rtf replace ///
	mtitle("Non-Academic track" "Academic track") noobs


********************************************************************************
*** PScore generieren ***
********************************************************************************
cap drop pscore
eststo L1: logit gym i.female i.pareduc alter2011 i.osten i.zusammenleben i.migration ///
	score5 speed5 math read if wave == 1, or
esttab L1 using "Output/logit.rtf", se rtf replace label nobase eform nogaps
cap drop temp
predict temp if wave == 1
sum temp
twoway (kdensity temp if gym == 1) (kdensity temp if gym == 0), xline(0.50 0.98) ///
	xtitle("Propensity score") ytitle("Density") ///
		legend(position(6) order(1 "Academic track" 2 "Other tracks"))
graph save "Output/Graphs/common_support", replace
graph export "Output/Graphs/common_support.png", replace as(png) width(1600)
bysort gym: sum temp
replace temp = .k if temp < 0.50		//Common support definieren
replace temp = .k if temp > 0.98 & !missing(temp)
bysort ID_t: egen pscore = max(temp)
drop temp
count if wave == 1
********************************************************************************
*** Abbildungen erzeugen ***
*do Dos/Graphs.do"				//Nur bei Bedarf laufen lassen




*** Einfache Modelle ***
*Welle 2*
khb logit aspi_ideal i.gym || mean_* ///
	if wave == 2, con(pscore) ape dis sum vce(cluster ID_i2)

*Welle 5*
khb logit aspi_ideal i.gym || mean_* ///
	if wave == 5, con(pscore) ape dis sum vce(cluster ID_i2)
	
	
*** Komplexe Modelle ***
global controls i.female math5 read5 score5 speed5 i.migration ///
	alter2011 i.zusammenleben 		//Osten kann nicht verwendet werden

*Welle 2*
khbtab logit aspi_ideal ib2.pareduc || $controls || i.gym || mean_* if wave == 2 ///
	, esttab tableoptions(se label b(3) nobase) vce(cluster ID_i2) ape
khb logit aspi_ideal ib2.pareduc || $controls i.gym mean_* if wave == 2, ///
	sum dis vce(cluster ID_i2) ape
	
	
*Welle 5*
khbtab logit aspi_ideal ib2.pareduc || $controls || i.gym || mean_* if wave == 5 ///
	, esttab tableoptions(se label b(3) nobase) vce(cluster ID_i2) ape
khb logit aspi_ideal ib2.pareduc || $controls i.gym mean_* if wave == 5, ///
	sum dis vce(cluster ID_i2) ape

	
********************************************************************************
*** Robustness ***
********************************************************************************
*Adding individual change of performance	
*Welle 5*
khb logit aspi_ideal i.gym || mean_* ///
	if wave == 5, con(pscore) dis vce(cluster ID_i2) ape
	
khb logit aspi_ideal i.gym || mean_* ///
	if wave == 5, con(pscore rankchange) dis vce(cluster ID_i2) ape
	
	
	
*Realistic aspirations*	
khb logit aspi_real i.gym || mean_* ///
	if wave == 2, con(pscore) dis sum vce(cluster ID_i2) ape
	
khb logit aspi_real i.gym || mean_* ///
	if wave == 5, con(pscore) dis sum vce(cluster ID_i2) ape
	
	
	
*EGP statt Bildung der Eltern*
global controls i.female math5 read5 score5 speed5 i.migration ///
	alter2011 i.zusammenleben 		//Osten kann nicht verwendet werden

	
	
*Welle 2*
khbtab logit aspi_ideal ib2.egp || $controls || i.gym || mean_* if wave == 2 ///
	, esttab tableoptions(se label b(3) nobase) vce(cluster ID_i2) ape
khb logit aspi_ideal ib2.egp || $controls i.gym mean_* if wave == 2, ///
	sum dis vce(cluster ID_i2) ape
	
	
*Welle 5*
khbtab logit aspi_ideal ib2.egp || $controls || i.gym || mean_* if wave == 5 ///
	, esttab tableoptions(se label b(3) nobase) vce(cluster ID_i2) ape
khb logit aspi_ideal ib2.egp || $controls i.gym mean_* if wave == 5, ///
	sum dis vce(cluster ID_i2) ape
	
	
cap log close
